pub struct SplunkConfig {
pub address: SocketAddr,
pub event: CodecConfig,
pub raw: CodecConfig,
/* private fields */
}Expand description
Configuration for the splunk_hec source.
Fields
address: SocketAddrThe socket address to listen for connections on.
The address must include a port.
event: CodecConfigCodec configuration applied to events received on /services/collector/event.
When decoding is set, Vector applies a second decoding pass after parsing the
HEC envelope. The envelope’s event field is passed through the codec,
and a single envelope can fan out to multiple events. Decode failures are
swallowed and do not return an error to the Splunk client.
The VRL codec can access HEC envelope metadata, such as host, sourcetype, and,
channel, and the authentication token via %splunk_hec.* paths and
get_secret!("splunk_hec_token") before the program executes.
raw: CodecConfigCodec configuration applied to events received on /services/collector/raw.
When decoding is set, the (decompressed) request body is fed through the
codec instead of being emitted as a single event. Decode failures are
swallowed and do not return an error to the Splunk client. When unset, the
endpoint preserves its existing behavior of one event per request body.